@@ -52,6 +52,7 @@ struct imp_dbh_st {
     bool see_if_its_a_number;
     int extended_result_codes;
     stmt_list_s * stmt_list;
+    bool began_transaction;
 };
 
 /* Statement Handle */
@@ -130,6 +131,9 @@ int sqlite_db_register_fts3_perl_tokenizer(pTHX_ SV *dbh);
 HV* _sqlite_status(int reset);
 HV* _sqlite_st_status(pTHX_ SV *sth, int reset);
 int sqlite_db_create_module(pTHX_ SV *dbh, const char *name, const char *perl_class);
+int sqlite_db_limit(pTHX_ SV *dbh, int id, int new_value);
+int sqlite_db_do_sv(SV *dbh, imp_dbh_t *imp_dbh, SV *sv_statement);
+void init_cxt();
 
 
 #ifdef SvUTF8_on
